//
//  WDSpeedTestManager.h
//  IWangDingSDK_SCSP
//
//  平台提供的宽带测速能力是根据当前调用SDK用户当前的网络环境“智能分配策略，以达到准确测试当前网络带宽
//  测速模块说明：用户可提供自定义测速策略，也可使用系统默认策略，当用户不配置策略时，SDK将默认使用系统默认策略
//  策略使用优秀级：用户配置策略 > 服务器后台配置策略 > 系统默认策略

//  Created by maoyuxiang on 2019/4/9.
//  Copyright © 2019年 iwangding. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "WDSpeedTestProtocol.h"

NS_ASSUME_NONNULL_BEGIN

/**
 宽带测速类：用于宽带的测速
 */
@interface WDSpeedTestManager : NSObject

+ (WDSpeedTestManager *)shareInstance;

/**
 测速配置策略
 */
@property(strong, nonatomic, readonly) WDSpeedTestConfig *config;

/**
 用户是否没有配置测速策略
 */
@property(assign, nonatomic, readonly) BOOL isUserNotSetConfig;

#pragma mark 测速
/**
 开始测速，使用默认配置

 @param target 测速回调代理
 */
- (void)startSpeedTestWithTarget:(id<WDSpeedTestDelegate>)target;

/**
 开始测速，使用自定义配置

 @param config 测速配置
 @param target 测速回调代理
 */
- (void)startSpeedTestWithConfig:(WDSpeedTestConfig *)config
                          target:(id<WDSpeedTestDelegate>)target;
/**
 取消测速
 */
- (void)cancelSpeedTest;

#pragma mark Ping

/**
 开始Ping

 @param URL host地址
 @param pingCount 次数
 @param timeout 超时时间(单位：秒)
 @param target 回调
 */
- (void)startPingWithURL:(NSString *)URL
                  pingCount:(NSInteger)pingCount
                    timeout:(float)timeout
                     target:(id<WDPingDelegate>)target;


/**
 取消Ping
 */
- (void)cancelPing;

@end

NS_ASSUME_NONNULL_END
